@@ -48,11 +48,27 @@ LOCALE_NAMES.update({
     "no_NO": {"name_en": "Norwegian", "name": "Norsk"},
 })
 
-disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
-opener = urllib.request.build_opener()
-opener.addheaders = [('User-agent', sickchill.oldbeard.common.USER_AGENT)]
-urllib.request.install_opener(opener)
+def set_opener(verify: bool):
+    disable_warnings(urllib3.exceptions.InsecureRequestWarning)
+
+    try:
+        from urllib.request import HTTPSHandler
+        context = ssl.SSLContext(ssl.PROTOCOL_SSLv23)
+        context.options |= ssl.OP_NO_SSLv2
+        context.verify_mode = ssl.CERT_REQUIRED if verify else ssl.CERT_NONE
+        context.check_hostname = verify
+        context.load_verify_locations(certifi.where(), None)
+        https_handler = HTTPSHandler(context=context, check_hostname=True)
+        opener = urllib.request.build_opener(https_handler)
+    except ImportError:
+        opener = urllib.request.build_opener()
+
+    opener.addheaders = [('User-agent', sickchill.oldbeard.common.USER_AGENT)]
+    urllib.request.install_opener(opener)
+
+
+set_opener(settings.SSL_VERIFY)
 
 # Override original shutil function to increase its speed by increasing its buffer to 10MB (optimal)
 copyfileobj_orig = shutil.copyfileobj
@@ -936,10 +952,14 @@ def get_show(name, tryIndexers=False):
 
     try:
         # check cache for show
-        cache = sickchill.oldbeard.name_cache.retrieveNameFromCache(name)
+        cache = sickchill.oldbeard.name_cache.get_id_from_name(name)
         if cache:
             fromCache = True
             showObj = Show.find(settings.showList, int(cache))
+        else:
+            show_matches = [show for show in settings.showList if (show.show_name and name == show.show_name) or (show.custom_name and name == show.custom_name)]
+            if len(show_matches) == 1:
+                showObj = show_matches[0]
 
         # try indexers
         if not showObj and tryIndexers:
@@ -957,7 +977,7 @@ def get_show(name, tryIndexers=False):
 
         # add show to cache
         if showObj and not fromCache:
-            sickchill.oldbeard.name_cache.addNameToCache(name, showObj.indexerid)
+            sickchill.oldbeard.name_cache.add_name(name, showObj.indexerid)
     except Exception as error:
         logger.debug(_("Error when attempting to find show: {0} in SickChill. Error: {1} ").format(name, error))
         logger.debug(traceback.format_exc())
