@@ -36,7 +36,7 @@ class Provider(TorrentProvider):
 
         for mode in search_strings:
             items = []
-            logger.debug(_(f'Search Mode: {mode}'))
+            logger.debug(_("Search Mode: {mode}".format(mode=mode)))
 
             for search_string in search_strings[mode]:
                 if mode == 'RSS':
@@ -80,7 +80,7 @@ class Provider(TorrentProvider):
                 download_url = item.find('link').text
 
                 entry = {'title': title, 'link': download_url, 'size': 333, 'seeders': 1, 'leechers': 1, 'hash': ''}
-                logger.debug(_(f'Found result: {title}'))
+                logger.debug(_('Found result: {title}'.format(title=title)))
 
                 entries.append(entry)
 
@@ -94,7 +94,7 @@ class Provider(TorrentProvider):
             'value': search_string
         }
 
-        logger.debug(_(f'Search String: {search_string}'))
+        logger.debug(_("Search String: {search_string}".format(search_string=search_string)))
         target_url = self.urls['search']
 
         data = self.get_url(target_url, params=search_params, returns='text')
@@ -179,7 +179,7 @@ class Provider(TorrentProvider):
 
                 release_title = '[HorribleSubs] {0}.[{1}]'.format(title, quality)
                 item = {'title': release_title, 'link': download_url, 'size': 333, 'seeders': 1, 'leechers': 1, 'hash': ''}
-                logger.debug(_(f'Found result: {release_title}'))
+                logger.debug(_('Found result: ') + f'{release_title}')
 
                 entries.append(item)
 
