@@ -99,12 +99,12 @@ class Provider(TorrentProvider):
 
         for mode in search_strings:
             items = []
-            logger.debug(_(f'Search Mode: {mode}'))
+            logger.debug(_("Search Mode: {mode}".format(mode=mode)))
 
             for search_string in search_strings[mode]:
 
                 if mode != 'RSS':
-                    logger.debug(_(f'Search String: {search_string}'))
+                    logger.debug(_("Search String: {search_string}".format(search_string=search_string)))
                 # search string needs to be normalized, single quotes are apparently not allowed on the site
                 # ç should also be replaced, people tend to use c instead
                 replace_chars = {
@@ -170,7 +170,7 @@ class Provider(TorrentProvider):
 
                             item = {'title': title, 'link': download_url, 'size': size, 'seeders': seeders, 'leechers': leechers, 'hash': ''}
                             if mode != 'RSS':
-                                logger.debug(_(f'Found result: {title} with {seeders} seeders and {leechers} leechers'))
+                                logger.debug(_('Found result: {title} with {seeders} seeders and {leechers} leechers'.format(title=title, seeders=seeders, leechers=leechers)))
 
                             items.append(item)
 
