@@ -233,7 +233,7 @@ class Home(WebRoot):
         if result:
             return _("SMS sent successfully")
         else:
-            return _(f"Problem sending SMS: {message}")
+            return _("Problem sending SMS: {message}".format(message=message))
 
     def testTelegram(self):
         telegram_id = self.get_body_argument('telegram_id')
@@ -242,7 +242,7 @@ class Home(WebRoot):
         if result:
             return _("Telegram notification succeeded. Check your Telegram clients to make sure it worked")
         else:
-            return _(f"Error sending Telegram notification: {message}")
+            return _("Error sending Telegram notification: {message}".format(message=message))
 
     def testJoin(self):
         join_id = self.get_body_argument('join_id')
@@ -252,7 +252,7 @@ class Home(WebRoot):
         if result:
             return _("join notification succeeded. Check your join clients to make sure it worked")
         else:
-            return _(f"Error sending join notification: {message}")
+            return _("Error sending join notification: {message}".format(message=message))
 
     def testGrowl(self):
         host = self.get_query_argument('host')
@@ -914,12 +914,12 @@ class Home(WebRoot):
 
     def sceneExceptions(self):
         show = self.get_query_argument('show')
-        exceptionsList = sickchill.oldbeard.scene_exceptions.get_all_scene_exceptions(show)
-        if not exceptionsList:
+        exeptions_list = sickchill.oldbeard.scene_exceptions.get_all_scene_exceptions(show)
+        if not exeptions_list:
             return _("No scene exceptions")
 
         out = []
-        for season, exceptions in iter(sorted(exceptionsList.items())):
+        for season, exceptions in iter(sorted(exeptions_list.items())):
             if season == -1:
                 season = "*"
             out.append("S" + str(season) + ": " + ", ".join(exceptions.names))
@@ -1033,10 +1033,10 @@ class Home(WebRoot):
         # Map custom exceptions
         exceptions = {}
 
-        if exceptions_list is not None:
+        if exceptions_list:
             # noinspection PyUnresolvedReferences
             for season in exceptions_list.split(','):
-                (season, shows) = season.split(':')
+                season, shows = season.split(':')
 
                 show_list = []
 
@@ -1165,10 +1165,13 @@ class Home(WebRoot):
             except CantUpdateShowException as e:
                 errors.append(_("Unable to update show: {error}").format(error=e))
 
+        import traceback
+        logger.debug('Updating show exceptions')
         try:
-            sickchill.oldbeard.scene_exceptions.update_scene_exceptions(show_obj.indexerid, exceptions)  # @UndefinedVdexerid)
+            sickchill.oldbeard.scene_exceptions.update_scene_exceptions(show_obj.indexerid, exceptions)
             time.sleep(cpu_presets[settings.CPU_PRESET])
         except CantUpdateShowException:
+            logger.debug(traceback.format_exc())
             errors.append(_("Unable to force an update on scene exceptions of the show."))
 
         if do_update_scene_numbering:
@@ -1557,7 +1560,7 @@ class Home(WebRoot):
         cache_db_con = db.DBConnection('cache.db', row_type="dict")
         results = cache_db_con.select(
             'SELECT * FROM results WHERE indexerid = ? AND season = ? AND episodes LIKE ? AND status != ? ORDER BY seeders DESC',
-            [show, season, '%|{}|%'.format(episode), FAILED])
+            [show, season, f'%|{episode}|%', FAILED])
 
         for result in results:
             episodes_list = [int(ep) for ep in result['episodes'].split('|') if ep]
